From 82b32c8c447aaa9d4572b442dddfe58bc669c488 Mon Sep 17 00:00:00 2001
From: Daksh Shah <daksh17336@iiitd.ac.in>
Date: Sun, 11 Mar 2018 09:43:57 +0530
Subject: [PATCH] Fixes #19964: Swiping on time slider enabled

---
 modules/gui/macosx/VLCControlsBarCommon.m |  3 +++
 modules/gui/macosx/VLCSlider.h            |  3 +++
 modules/gui/macosx/VLCSlider.m            | 26 ++++++++++++++++++++++++++
 3 files changed, 32 insertions(+)

diff --git a/modules/gui/macosx/VLCControlsBarCommon.m b/modules/gui/macosx/VLCControlsBarCommon.m
index 391371706e..996b9aa92f 100644
--- a/modules/gui/macosx/VLCControlsBarCommon.m
+++ b/modules/gui/macosx/VLCControlsBarCommon.m
@@ -276,6 +276,9 @@ - (IBAction)timeSliderAction:(id)sender
         case NSLeftMouseDragged:
             f_updated = [sender floatValue];
             break;
+        case NSScrollWheel:
+            f_updated = [sender floatValue];
+            break;
 
         default:
             return;
diff --git a/modules/gui/macosx/VLCSlider.h b/modules/gui/macosx/VLCSlider.h
index ba95b63ab0..36e8659c8c 100644
--- a/modules/gui/macosx/VLCSlider.h
+++ b/modules/gui/macosx/VLCSlider.h
@@ -28,6 +28,9 @@
 @property (nonatomic, getter=getIndefinite,setter=setIndefinite:) BOOL indefinite;
 @property (nonatomic, getter=getKnobHidden,setter=setKnobHidden:) BOOL isKnobHidden;
 
+/* Indicates if the slider is scrollable with the mouse or trackpad scrollwheel. */
+@property (readwrite) BOOL isScrollable;
+
 - (void)setSliderStyleLight;
 - (void)setSliderStyleDark;
 
diff --git a/modules/gui/macosx/VLCSlider.m b/modules/gui/macosx/VLCSlider.m
index 245c4faab0..f76d6ee94c 100644
--- a/modules/gui/macosx/VLCSlider.m
+++ b/modules/gui/macosx/VLCSlider.m
@@ -33,6 +33,7 @@ - (instancetype)initWithCoder:(NSCoder *)coder
     if (self) {
         NSAssert([self.cell isKindOfClass:[VLCSliderCell class]],
                  @"VLCSlider cell is not VLCSliderCell");
+        _isScrollable = YES;
     }
     return self;
 }
@@ -42,6 +43,31 @@ + (Class)cellClass
     return [VLCSliderCell class];
 }
 
+- (void)scrollWheel:(NSEvent *)event
+{
+    if (!_isScrollable)
+        return [super scrollWheel:event];
+    double increment;
+    CGFloat deltaY = [event scrollingDeltaY];
+    double range = [self maxValue] - [self minValue];
+    
+    // Scroll less for high precision, else it's too fast
+    if (event.hasPreciseScrollingDeltas) {
+        increment = (range * 0.002) * deltaY;
+    } else {
+        if (deltaY == 0.0)
+            return;
+        increment = (range * 0.01 * deltaY);
+    }
+    
+    // If scrolling is inversed, increment in other direction
+    if (!event.isDirectionInvertedFromDevice)
+        increment = -increment;
+    
+    [self setDoubleValue:self.doubleValue - increment];
+    [self sendAction:self.action to:self.target];
+}
+
 // Workaround for 10.7
 // http://stackoverflow.com/questions/3985816/custom-nsslidercell
 - (void)setNeedsDisplayInRect:(NSRect)invalidRect {
-- 
2.14.3 (Apple Git-98)

